.. toctree::
   :hidden:

   Installation <installation>
   usage
   concepts

   guide-config
   guide-editor-env
   guide-intro-cli-and-editor
   guide-exit-save-undoredo
   guide-jumping-around
   guide-editing-facts
   guide-copy-paste
   guide-combinations
   guide-nudging-time

   Developer Credits <authors>
   Software License <license>
   Help Us Improve <contributing>
   API Reference <modules>
   Project History <history>

.. include:: ../README.rst

